@@ -23,13 +23,15 @@ Usage::
     list_luna_clients_paginator: ListLunaClientsPaginator = client.get_paginator("list_luna_clients")
     ```
 """
-from mypy_boto3_cloudhsm.client import CloudHSMClient as Client, CloudHSMClient
+from mypy_boto3_cloudhsm.client import CloudHSMClient
 from mypy_boto3_cloudhsm.paginator import (
     ListHapgsPaginator,
     ListHsmsPaginator,
     ListLunaClientsPaginator,
 )
 
+Client = CloudHSMClient
+
 
 __all__ = (
     "Client",
